==> haskell-pqueue-1.5.0.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pqueue.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pqueue
version:              1.5.0.0
visibility:           public
id:                   pqueue-1.5.0.0-Hsg3Fi71lpRGdBoZQUXCYH
key:                  pqueue-1.5.0.0-Hsg3Fi71lpRGdBoZQUXCYH
license:              BSD-3-Clause
maintainer:
    Lennart Spitzner <hexagoxel@hexagoxel.de>,
    Louis Wasserman <wasserman.louis@gmail.com>,
    konsumlamm <konsumlamm@gmail.com>,
    David Feuer <David.Feuer@gmail.com>

author:               Louis Wasserman
stability:            experimental
homepage:             https://github.com/lspitzner/pqueue
synopsis:             Reliable, persistent, fast priority queues.
description:
    A fast, reliable priority queue implementation based on a binomial heap.

category:             Data Structures
abi:                  47406145429334c25a456cb5c256a7bb
exposed:              True
exposed-modules:
    Data.PQueue.Max Data.PQueue.Min Data.PQueue.Prio.Max
    Data.PQueue.Prio.Min

hidden-modules:
    Data.PQueue.Prio.Internals Data.PQueue.Internals
    BinomialQueue.Internals BinomialQueue.Min BinomialQueue.Max
    Data.PQueue.Internals.Down Data.PQueue.Internals.Foldable
    Data.PQueue.Prio.Max.Internals Nattish

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pqueue-1.5.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pqueue-1.5.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pqueue-1.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pqueue
hs-libraries:         HSpqueue-1.5.0.0-Hsg3Fi71lpRGdBoZQUXCYH
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    indexed-traversable-0.1.4-3Mq4EBXbmCUGTMDLGSN4EO

haddock-interfaces:   /usr/share/doc/haskell-pqueue/html/pqueue.haddock
haddock-html:         /usr/share/doc/haskell-pqueue/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pqueue-1.5.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pqueue.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pqueue
version:              1.5.0.0
visibility:           public
id:                   pqueue-1.5.0.0-CBV8XyKTQW2LRZdhOEaqa8
key:                  pqueue-1.5.0.0-CBV8XyKTQW2LRZdhOEaqa8
license:              BSD-3-Clause
maintainer:
    Lennart Spitzner <hexagoxel@hexagoxel.de>,
    Louis Wasserman <wasserman.louis@gmail.com>,
    konsumlamm <konsumlamm@gmail.com>,
    David Feuer <David.Feuer@gmail.com>

author:               Louis Wasserman
stability:            experimental
homepage:             https://github.com/lspitzner/pqueue
synopsis:             Reliable, persistent, fast priority queues.
description:
    A fast, reliable priority queue implementation based on a binomial heap.

category:             Data Structures
abi:                  f30b267f66f193770091262a8e870a67
exposed:              True
exposed-modules:
    Data.PQueue.Max Data.PQueue.Min Data.PQueue.Prio.Max
    Data.PQueue.Prio.Min

hidden-modules:
    Data.PQueue.Prio.Internals Data.PQueue.Internals
    BinomialQueue.Internals BinomialQueue.Min BinomialQueue.Max
    Data.PQueue.Internals.Down Data.PQueue.Internals.Foldable
    Data.PQueue.Prio.Max.Internals Nattish

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pqueue-1.5.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pqueue-1.5.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pqueue-1.5.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pqueue
hs-libraries:         HSpqueue-1.5.0.0-CBV8XyKTQW2LRZdhOEaqa8
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    indexed-traversable-0.1.4-I4BD8iHmRbP9SiNqQBAmeX

haddock-interfaces:   /usr/share/doc/haskell-pqueue/html/pqueue.haddock
haddock-html:         /usr/share/doc/haskell-pqueue/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
